==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/nl/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Speciale velden',
    'field'		                => 'Veld',
    'about_fieldsets_title'		=> 'Over veldverzamelingen',
    'about_fieldsets_text'		=> 'Veldverzamelingen stellen je in staat groepen van aangepaste velden te maken die vaak worden hergebruikt voor specifieke soorten asset modellen.',
    'custom_format'             => 'Aangepaste indeling...',
    'encrypt_field'      	        => 'Encrypt de waarde van dit veld in de database',
    'encrypt_field_help'      => 'Waarschuwing: Versleutelen van dit veld maakt het onmogelijk om hierop te zoeken.',
    'encrypted'      	        => 'Versleuteld',
    'fieldset'      	        => 'Veldverzameling',
    'qty_fields'      	      => 'Aantal Velden',
    'fieldsets'      	        => 'Veldverzamelingen',
    'fieldset_name'           => 'Veldverzamelin naam',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaarden',
    'field_values_help'       => 'Voeg selecteerbare optie toe, één per regel. Alle blanco regels behalve de eerste regel zullen worden genegeerd.',
    'field_element'           => 'Formulier element',
    'field_element_short'     => 'Element',
    'field_format'            => 'Stijl',
    'field_custom_format'     => 'Aangepaste stijl',
    'field_custom_format_help'     => 'Dit veld laat u toe om een regex expressie te gebruiken om te valideren. Het moet beginnen met "regex:" - bijvoorbeeld, om een waarde in een speciaal veld te valideren dat een geldig IMEI nummer (15 cijfers) bevat, gebruik je <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Verplicht',
    'req'   		              => 'Ndz.',
    'used_by_models'   		    => 'Gebruikt door modellen',
    'order'   		            => 'Bestelling',
    'create_fieldset'         => 'Nieuwe veldset',
    'create_field'            => 'Nieuw aangepast veld',
    'value_encrypted'      	        => 'De waarde van dit veld is versleuteld in de database. Alleen beheerders zullen de onversleutelde waarde kunnen weergeven.',
    'show_in_email'     => 'De waarde van dit veld opnemen in de checkout-e-mails die naar de gebruiker zijn verzonden? Versleutelde velden kunnen niet worden opgenomen in e-mails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/nl/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Speciale velden',
    'manage'                    => 'Beheren',
    'field'		                => 'Veld',
    'about_fieldsets_title'		=> 'Over veldverzamelingen',
    'about_fieldsets_text'		=> 'Veldverzamelingen stellen je in staat groepen van aangepaste velden te maken die vaak worden hergebruikt voor specifieke soorten asset modellen.',
    'custom_format'             => 'Aangepaste Regex formaat...',
    'encrypt_field'      	        => 'Encrypt de waarde van dit veld in de database',
    'encrypt_field_help'      => 'Waarschuwing: Versleutelen van dit veld maakt het onmogelijk om hierop te zoeken.',
    'encrypted'      	        => 'Versleuteld',
    'fieldset'      	        => 'Veldverzameling',
    'qty_fields'      	      => 'Aantal Velden',
    'fieldsets'      	        => 'Veldverzamelingen',
    'fieldset_name'           => 'Veldverzamelin naam',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaarden',
    'field_values_help'       => 'Voeg selecteerbare optie toe, één per regel. Alle blanco regels behalve de eerste regel zullen worden genegeerd.',
    'field_element'           => 'Formulier element',
    'field_element_short'     => 'Element',
    'field_format'            => 'Stijl',
    'field_custom_format'     => 'Aangepaste stijl',
    'field_custom_format_help'     => 'Dit veld laat u toe om een regex expressie te gebruiken om te valideren. Het moet beginnen met "regex:" - bijvoorbeeld, om een waarde in een speciaal veld te valideren dat een geldig IMEI nummer (15 cijfers) bevat, gebruik je <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Verplicht',
    'req'   		              => 'Ndz.',
    'used_by_models'   		    => 'Gebruikt door modellen',
    'order'   		            => 'Bestelling',
    'create_fieldset'         => 'Nieuwe veldset',
    'create_fieldset_title' => 'Maak een nieuwe veldset aan',
    'create_field'            => 'Nieuw aangepast veld',
    'create_field_title' => 'Maak een nieuw aangepast veld',
    'value_encrypted'      	        => 'De waarde van dit veld is versleuteld in de database. Alleen beheerders zullen de onversleutelde waarde kunnen weergeven.',
    'show_in_email'     => 'De waarde van dit veld opnemen in de checkout-e-mails die naar de gebruiker zijn verzonden? Versleutelde velden kunnen niet worden opgenomen in e-mails.',
    'help_text' => 'Help tekst',
    'help_text_description' => 'Dit is een optionele tekst die onder de formulierelementen verschijnt terwijl een asset wordt bewerkt om context op te geven in het veld.',
    'about_custom_fields_title' => 'Over Aangepaste Velden',
    'about_custom_fields_text' => 'Met Aangepaste velden kun je willekeurige attributen toevoegen aan assets.',
    'add_field_to_fieldset' => 'Veld toevoegen aan Fieldset',
    'make_optional' => 'Vereist - klik om optioneel te maken',
    'make_required' => 'Optioneel - klik om vereist te maken',
    'reorder' => 'Herordenen',
    'db_field' => 'DB veld',
    'db_convert_warning' => 'WAARSCHUWING. Dit veld staat in de tabel met aangepaste velden als <code> :db_column </code> maar moet :expected </code> zijn.',
    'is_unique' => 'Deze waarde moet uniek zijn voor alle assets',
    'unique' => 'Uniek',
];
